@@ -32,6 +32,7 @@
                                 "',member='" CALL_INCOMING_SIG "'"
 
 osso_context_t* osso;
+int bRunning = TRUE;
 extern int bKeepDisplayOn;
 extern int bAutosaveOnExit;
 extern char keys_config_file[MAXPATHLEN];
@@ -88,13 +89,21 @@ static void *displayThread(void *arg)
 												    "com.nokia.mce.request",
 												    "req_display_blanking_pause");
 	if (msg && system_bus) {
-		while (1) {
+		bRunning = TRUE;
+		while (bRunning) {
 			dbus_connection_send(system_bus, msg, NULL);
 			dbus_connection_flush(system_bus);
-			usleep(4000000);
+			int i = 0;
+			for (i=0; i<8; i++){
+				usleep(500000);
+				if (!bRunning)
+					break;
+			}
 		}
+		dbus_message_unref(msg);
 	}
 
+	pthread_exit(0);
 	return NULL;
 }
 
@@ -136,6 +145,7 @@ void change_disc()
 {
 	GtkWidget *dialog;
 	dialog = hildon_file_chooser_dialog_new (GTK_WINDOW(window), GTK_FILE_CHOOSER_ACTION_OPEN);
+    gtk_window_set_title (GTK_WINDOW (dialog), "Change disc");
 
 	char currentFile[MAXPATHLEN];
 	strcpy(currentFile, GetIsoFile());
@@ -157,6 +167,8 @@ void change_disc()
 	gtk_file_filter_add_pattern (filter,"*.ZNX");
 	gtk_file_filter_add_pattern (filter,"*.pbp");
 	gtk_file_filter_add_pattern (filter,"*.PBP");
+	gtk_file_filter_add_pattern (filter,"*.mdf");
+	gtk_file_filter_add_pattern (filter,"*.MDF");
 	gtk_file_chooser_set_filter (GTK_FILE_CHOOSER (dialog),filter);
 
 	if (gtk_dialog_run (GTK_DIALOG (dialog)) == GTK_RESPONSE_OK) {
@@ -282,13 +294,39 @@ inline void key_press_event(int key2,int type)
 	int  psxkey1 = -1, psxkey2 = -1;
 	int key=keymap[key2];
 
-	if (key < 0){
+	if (key < 0)
 		return;
-	}
 
-	if (key < ARRAY_SIZE(keymap2))
+	//printf("Key: %i %s\n", key2, type == 1 ? "Pressed" : (type == 2 ? "Released" : "Unknown"));
+	if (key < ARRAY_SIZE(keymap2)){
 		psxkey1 = keymap2[key];
-	else switch (key) {
+		/*switch(keymap2[key]){
+			case DKEY_LEFT:
+				printf("  DKEY_LEFT\n");
+				break;
+			case DKEY_RIGHT:
+				printf("  DKEY_RIGHT\n");
+				break;
+			case DKEY_UP:
+				printf("  DKEY_UP\n");
+				break;
+			case DKEY_DOWN:
+				printf("  DKEY_DOWN\n");
+				break;
+			case DKEY_CIRCLE:
+				printf("  DKEY_CIRCLE\n");
+				break;
+			case DKEY_CROSS:
+				printf("  DKEY_CROSS\n");
+				break;
+			case DKEY_TRIANGLE:
+				printf("  DKEY_TRIANGLE\n");
+				break;
+			case DKEY_SQUARE:
+				printf("  DKEY_SQUARE\n");
+				break;
+		}*/
+	}else switch (key) {
 		case 14:
 			if (bAutosaveOnExit){
 			    show_notification("Autosaving");
@@ -450,7 +488,7 @@ int maemo_init(int *argc, char ***argv)
 
 	if (bKeepDisplayOn){
 		if (pthread_create(&display_thread, NULL, displayThread, NULL))
-			printf("Failed to create display thread.\n");
+			printf("Failed to create display thread.\n");		
 	}
 
 	return 0;
@@ -458,6 +496,11 @@ int maemo_init(int *argc, char ***argv)
 
 void maemo_finish()
 {
+	if (display_thread > 0){
+		bRunning = FALSE;
+		pthread_join(display_thread, NULL);
+	}
+
 	if (osso){
 		osso_deinitialize(osso);
 		osso = NULL;
@@ -576,8 +619,26 @@ void plat_step_volume(int is_up)
 {
 }
 
-void plat_trigger_vibrate(void)
+void plat_trigger_vibrate(int is_strong)
 {
+	DBusConnection* system_bus = (DBusConnection*)osso_get_sys_dbus_connection(osso);
+	DBusMessageIter args;
+	DBusMessage*msg = dbus_message_new_method_call("com.nokia.mce",
+												   "/com/nokia/mce/request",
+												   "com.nokia.mce.request",
+												   "req_start_manual_vibration");
+	if (msg) {
+		dbus_message_iter_init_append(msg, &args);
+		int speed = is_strong ? 200 : 100;
+		int duration = 10;
+		if (dbus_message_iter_append_basic(&args, DBUS_TYPE_INT32, &speed)) {
+			if (dbus_message_iter_append_basic(&args, DBUS_TYPE_INT32, &duration)) {
+				dbus_connection_send(system_bus, msg, NULL);
+				//dbus_connection_flush(system_bus);
+			}
+		}
+		dbus_message_unref(msg);
+	}
 }
 
 void plat_minimize(void)
