@@ -20,6 +20,7 @@
 #include "../plugins/dfinput/main.h"
 #include "maemo_common.h"
 
+extern int in_enable_vibration;
 extern int cycle_multiplier;
 extern int in_type1, in_type2;
 
@@ -70,6 +71,7 @@ void PrintHelp()
  	printf("  -autosave      : Enable auto save on exit\n");
 	printf("  -accel         : Enable accelerometer\n");
 	printf("  -analog        : Use analog pad for accel\n");
+	printf("  -vibration     : Activate vibration\n");
 	printf("  -sens VALUE    : Set accelerometer sens [0-1000]\n");
     printf("                   (Default 150)\n");
 	printf("  -ydef VALUE    : Set accelerometer y zero [0-1000]\n");
@@ -252,6 +254,7 @@ int maemo_main(int argc, char **argv)
 
 		else if (!strcmp(argv[i], "-cpuclock")) 	        cycle_multiplier = 10000 / atol(argv[++i]);
 		else if (!strcmp(argv[i], "-analog")) 	            in_type1 = PSE_PAD_TYPE_ANALOGPAD;
+		else if (!strcmp(argv[i], "-vibration")) 	        { in_type1 = PSE_PAD_TYPE_ANALOGPAD; in_enable_vibration = 1; }
 		else if (!strcmp(argv[i], "-sens")) 				accelOptions.sens = atol(argv[++i]);
 		else if (!strcmp(argv[i], "-ydef")) 				accelOptions.y_def = atol(argv[++i]);
 		else if (!strcmp(argv[i], "-max")) 				    accelOptions.maxValue = atol(argv[++i]);
@@ -281,6 +284,7 @@ int maemo_main(int argc, char **argv)
 		}
 	}
 
+	in_enable_vibration = 1;
 	hildon_init(&argc, &argv);
 
 	if (cdfile) {
