@@ -61,7 +61,7 @@ static Settings settings = {
 };
 
 // the number of bytes written in SoundFeedStreamData
-const int mixlen = 3240;
+const int mixlen = 3240 * 3;
 
 // used to calculate how much space is used in the buffer, for debugging purposes
 //int maxlength = 0;
@@ -119,7 +119,6 @@ static void stream_latency_update_cb (pa_stream *stream, void *userdata)
 
      if ((stream == NULL) || (dev == NULL))
 	  return;
-
      pa_threaded_mainloop_signal (dev->mainloop, 0);
 }
 
@@ -298,9 +297,6 @@ void RemoveSound (void)
 unsigned long SoundGetBytesBuffered (void)
 {
      int free_space;
-     //int error_code;
-     //long latency;
-     //int playing = 0;
 
      if ((device.mainloop == NULL) || (device.api == NULL) || ( device.context == NULL) || (device.stream == NULL))
      	  return SOUNDSIZE;
@@ -311,7 +307,7 @@ unsigned long SoundGetBytesBuffered (void)
 
      //fprintf (stderr, "Free space: %d\n", free_space);
      //fprintf (stderr, "Used space: %d\n", maxlength - free_space);
-     if  (free_space < mixlen * 3)
+     if  (free_space < mixlen)
      {
 	  // Don't buffer anymore, just play
 	  //fprintf (stderr, "Not buffering.\n");
@@ -331,9 +327,6 @@ unsigned long SoundGetBytesBuffered (void)
 
 void SoundFeedStreamData (unsigned char *pSound, long lBytes)
 {
-     //int error_code;
-     //int size;
-
      if (device.mainloop != NULL)
      {
 	  pa_threaded_mainloop_lock (device.mainloop);
@@ -344,8 +337,8 @@ void SoundFeedStreamData (unsigned char *pSound, long lBytes)
 	  else
 	  {
 	       //fprintf (stderr, "Wrote %d bytes\n", lBytes);
-	       pa_threaded_mainloop_unlock (device.mainloop);
 	  }
+	  pa_threaded_mainloop_unlock (device.mainloop);
      }
 }
 #endif
